firebase

package module
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package firebase provides a Firebase App component with launcher lifecycle and health check integration.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Component

type Component interface {
	launcher.Component
	health.Checkable
	Provider
}

Component adds lifecycle management and health check to Provider.

func New

func New(logger logz.Logger, cfg Config) Component

New returns a firebase Component. Call lc.Append(fb) to manage its lifecycle.

type Config

type Config struct {
	// ProjectID is the Google Cloud Project ID.
	ProjectID string `env:"FIREBASE_PROJECT_ID,required"`
}

Config holds Firebase configuration.

type Provider

type Provider interface {
	App() *fb.App
}

Provider is the minimal interface for consumers that only need the firebase App.

Jump to