package
module
Version:
v0.9.0
Opens a new window with list of versions in this module.
Published: Mar 19, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package firebase provides a Firebase App component with launcher lifecycle
and health check integration.
Component adds lifecycle management and health check to Provider.
New returns a firebase Component. Call lc.Append(fb) to manage its lifecycle.
type Config struct {
ProjectID string `env:"FIREBASE_PROJECT_ID,required"`
}
Config holds Firebase configuration.
type Provider interface {
App() *fb.App
}
Provider is the minimal interface for consumers that only need the firebase App.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.